==> igniteui-webcomponents-maps-4.7.2.tgz: package/esm5/lib/igc-geographic-contour-line-series-component.js <==
import { __extends } from "tslib";
import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { IgcValueBrushScaleComponent } from "igniteui-webcomponents-charts";
import { IgcContourValueResolverComponent } from "igniteui-webcomponents-charts";
import { IgcTriangulationStatusEventArgs } from "igniteui-webcomponents-core";
import { IgcGeographicXYTriangulatingSeriesComponent } from "./igc-geographic-xy-triangulating-series-component";
import { GeographicContourLineSeries } from "./GeographicContourLineSeries";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Represents a class for Geographic Contour Series displayed on a map.
*/
var IgcGeographicContourLineSeriesComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcGeographicContourLineSeriesComponent, _super);
    function IgcGeographicContourLineSeriesComponent() {
        var _this = _super.call(this) || this;
        _this._triangulationStatusChanged = null;
        _this._triangulationStatusChanged_wrapped = null;
        return _this;
    }
    IgcGeographicContourLineSeriesComponent.prototype.createImplementation = function () {
        return new GeographicContourLineSeries();
    };
    Object.defineProperty(IgcGeographicContourLineSeriesComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicContourLineSeriesComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcGeographicContourLineSeriesComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcGeographicContourLineSeriesComponent, "observedAttributes", {
        get: function () {
            if (IgcGeographicContourLineSeriesComponent._observedAttributesIgcGeographicContourLineSeriesComponent == null) {
                var names = getAllPropertyNames(IgcGeographicContourLineSeriesComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicContourLineSeriesComponent._observedAttributesIgcGeographicContourLineSeriesComponent = names;
            }
            return IgcGeographicContourLineSeriesComponent._observedAttributesIgcGeographicContourLineSeriesComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicContourLineSeriesComponent.register = function () {
        if (!IgcGeographicContourLineSeriesComponent._isElementRegistered) {
            IgcGeographicContourLineSeriesComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcGeographicContourLineSeriesComponent.htmlTagName, IgcGeographicContourLineSeriesComponent);
        }
    };
    Object.defineProperty(IgcGeographicContourLineSeriesComponent.prototype, "isLineContour", {
        /**
         * Gets whether the current series shows a line contour shape.
        */
        get: function () {
            return this.i.ex;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicContourLineSeriesComponent.prototype, "valueMemberPath", {
        /**
         * The name of the property from which to retrieve the numeric values from the ItemsSource items.
        */
        get: function () {
            return this.i.u4;
        },
        set: function (v) {
            this.i.u4 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicContourLineSeriesComponent.prototype, "fillScale", {
        /**
         * The ValueBrushScale to use when determining Brushes for each contour line, based on the values found in ValueMemberPath.
        */
        get: function () {
            var r = this.i.u0;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgcValueBrushScaleComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.u0 = null : this.i.u0 = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicContourLineSeriesComponent.prototype, "actualFillScale", {
        /**
         * Gets actual fill scale that is set on the FillScale property or default FillScale
        */
        get: function () {
            var r = this.i.uz;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgcValueBrushScaleComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.uz = null : this.i.uz = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicContourLineSeriesComponent.prototype, "valueResolver", {
        /**
         * The ContourValueResolver used to determine the numeric values of contours.
        */
        get: function () {
            var r = this.i.uw;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgcContourValueResolverComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.uw = null : this.i.uw = v.i;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicContourLineSeriesComponent.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.fillScale && this.fillScale.name && this.fillScale.name == name) {
            return this.fillScale;
        }
        if (this.actualFillScale && this.actualFillScale.name && this.actualFillScale.name == name) {
            return this.actualFillScale;
        }
        if (this.valueResolver && this.valueResolver.name && this.valueResolver.name == name) {
            return this.valueResolver;
        }
        return null;
    };
    IgcGeographicContourLineSeriesComponent.prototype._styling = function (container, component, parent) {
        _super.prototype._styling.call(this, container, component, parent);
        this._inStyling = true;
        if (this.fillScale && this.fillScale._styling) {
            this.fillScale._styling(container, component, this);
        }
        if (this.actualFillScale && this.actualFillScale._styling) {
            this.actualFillScale._styling(container, component, this);
        }
        if (this.valueResolver && this.valueResolver._styling) {
            this.valueResolver._styling(container, component, this);
        }
        this._inStyling = false;
    };
    Object.defineProperty(IgcGeographicContourLineSeriesComponent.prototype, "triangulationStatusChanged", {
        /**
         * Raised when the status of an ongoing Triangulation has changed.
        */
        get: function () {
            return this._triangulationStatusChanged;
        },
        set: function (ev) {
            var _this = this;
            if (this._triangulationStatusChanged_wrapped !== null) {
                this.i.triangulationStatusChanged = delegateRemove(this.i.triangulationStatusChanged, this._triangulationStatusChanged_wrapped);
                this._triangulationStatusChanged_wrapped = null;
                this._triangulationStatusChanged = null;
            }
            this._triangulationStatusChanged = ev;
            this._triangulationStatusChanged_wrapped = function (o, e) {
                var outerArgs = new IgcTriangulationStatusEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeTriangulationStatusChanged) {
                    _this.beforeTriangulationStatusChanged(_this, outerArgs);
                }
                if (_this._triangulationStatusChanged) {
                    _this._triangulationStatusChanged(_this, outerArgs);
                }
            };
            this.i.triangulationStatusChanged = delegateCombine(this.i.triangulationStatusChanged, this._triangulationStatusChanged_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicContourLineSeriesComponent._observedAttributesIgcGeographicContourLineSeriesComponent = null;
    IgcGeographicContourLineSeriesComponent.htmlTagName = "igc-geographic-contour-line-series";
    IgcGeographicContourLineSeriesComponent._isElementRegistered = false;
    return IgcGeographicContourLineSeriesComponent;
}(IgcGeographicXYTriangulatingSeriesComponent));
export { IgcGeographicContourLineSeriesComponent };

==> igniteui-webcomponents-maps-5.4.1.tgz: package/esm5/lib/igc-geographic-contour-line-series-component.js <==
import { __extends } from "tslib";
import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { IgcValueBrushScaleComponent } from "igniteui-webcomponents-charts";
import { IgcContourValueResolverComponent } from "igniteui-webcomponents-charts";
import { IgcTriangulationStatusEventArgs } from "igniteui-webcomponents-core";
import { IgcGeographicXYTriangulatingSeriesComponent } from "./igc-geographic-xy-triangulating-series-component";
import { GeographicContourLineSeries } from "./GeographicContourLineSeries";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Represents a class for Geographic Contour Series displayed on a map.
*/
var IgcGeographicContourLineSeriesComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcGeographicContourLineSeriesComponent, _super);
    function IgcGeographicContourLineSeriesComponent() {
        var _this = _super.call(this) || this;
        _this._triangulationStatusChanged = null;
        _this._triangulationStatusChanged_wrapped = null;
        return _this;
    }
    IgcGeographicContourLineSeriesComponent.prototype.createImplementation = function () {
        return new GeographicContourLineSeries();
    };
    Object.defineProperty(IgcGeographicContourLineSeriesComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicContourLineSeriesComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcGeographicContourLineSeriesComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcGeographicContourLineSeriesComponent, "observedAttributes", {
        get: function () {
            if (IgcGeographicContourLineSeriesComponent._observedAttributesIgcGeographicContourLineSeriesComponent == null) {
                var names = getAllPropertyNames(IgcGeographicContourLineSeriesComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicContourLineSeriesComponent._observedAttributesIgcGeographicContourLineSeriesComponent = names;
            }
            return IgcGeographicContourLineSeriesComponent._observedAttributesIgcGeographicContourLineSeriesComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicContourLineSeriesComponent.register = function () {
        if (!IgcGeographicContourLineSeriesComponent._isElementRegistered) {
            IgcGeographicContourLineSeriesComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcGeographicContourLineSeriesComponent.htmlTagName, IgcGeographicContourLineSeriesComponent);
        }
    };
    Object.defineProperty(IgcGeographicContourLineSeriesComponent.prototype, "isLineContour", {
        /**
         * Gets whether the current series shows a line contour shape.
        */
        get: function () {
            return this.i.fj;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicContourLineSeriesComponent.prototype, "valueMemberPath", {
        /**
         * The name of the property from which to retrieve the numeric values from the ItemsSource items.
        */
        get: function () {
            return this.i.x1;
        },
        set: function (v) {
            this.i.x1 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicContourLineSeriesComponent.prototype, "fillScale", {
        /**
         * The ValueBrushScale to use when determining Brushes for each contour line, based on the values found in ValueMemberPath.
        */
        get: function () {
            var r = this.i.xx;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgcValueBrushScaleComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.xx = null : this.i.xx = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicContourLineSeriesComponent.prototype, "actualFillScale", {
        /**
         * Gets actual fill scale that is set on the FillScale property or default FillScale
        */
        get: function () {
            var r = this.i.xw;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgcValueBrushScaleComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.xw = null : this.i.xw = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicContourLineSeriesComponent.prototype, "valueResolver", {
        /**
         * The ContourValueResolver used to determine the numeric values of contours.
        */
        get: function () {
            var r = this.i.xt;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgcContourValueResolverComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.xt = null : this.i.xt = v.i;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicContourLineSeriesComponent.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.fillScale && this.fillScale.name && this.fillScale.name == name) {
            return this.fillScale;
        }
        if (this.actualFillScale && this.actualFillScale.name && this.actualFillScale.name == name) {
            return this.actualFillScale;
        }
        if (this.valueResolver && this.valueResolver.name && this.valueResolver.name == name) {
            return this.valueResolver;
        }
        return null;
    };
    IgcGeographicContourLineSeriesComponent.prototype._styling = function (container, component, parent) {
        _super.prototype._styling.call(this, container, component, parent);
        this._inStyling = true;
        if (this.fillScale && this.fillScale._styling) {
            this.fillScale._styling(container, component, this);
        }
        if (this.actualFillScale && this.actualFillScale._styling) {
            this.actualFillScale._styling(container, component, this);
        }
        if (this.valueResolver && this.valueResolver._styling) {
            this.valueResolver._styling(container, component, this);
        }
        this._inStyling = false;
    };
    Object.defineProperty(IgcGeographicContourLineSeriesComponent.prototype, "triangulationStatusChanged", {
        /**
         * Raised when the status of an ongoing Triangulation has changed.
        */
        get: function () {
            return this._triangulationStatusChanged;
        },
        set: function (ev) {
            var _this = this;
            if (this._triangulationStatusChanged_wrapped !== null) {
                this.i.triangulationStatusChanged = delegateRemove(this.i.triangulationStatusChanged, this._triangulationStatusChanged_wrapped);
                this._triangulationStatusChanged_wrapped = null;
                this._triangulationStatusChanged = null;
            }
            this._triangulationStatusChanged = ev;
            this._triangulationStatusChanged_wrapped = function (o, e) {
                var outerArgs = new IgcTriangulationStatusEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeTriangulationStatusChanged) {
                    _this.beforeTriangulationStatusChanged(_this, outerArgs);
                }
                if (_this._triangulationStatusChanged) {
                    _this._triangulationStatusChanged(_this, outerArgs);
                }
            };
            this.i.triangulationStatusChanged = delegateCombine(this.i.triangulationStatusChanged, this._triangulationStatusChanged_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicContourLineSeriesComponent._observedAttributesIgcGeographicContourLineSeriesComponent = null;
    IgcGeographicContourLineSeriesComponent.htmlTagName = "igc-geographic-contour-line-series";
    IgcGeographicContourLineSeriesComponent._isElementRegistered = false;
    return IgcGeographicContourLineSeriesComponent;
}(IgcGeographicXYTriangulatingSeriesComponent));
export { IgcGeographicContourLineSeriesComponent };
